==> infinispan-server-hotrod-9.2.4.Final-sources.jar: org/infinispan/server/hotrod/iteration/IterableIterationResult.java <==
package org.infinispan.server.hotrod.iteration;

import java.util.BitSet;
import java.util.List;
import java.util.Set;

import org.infinispan.container.entries.CacheEntry;
import org.infinispan.server.hotrod.OperationStatus;

/**
 * @author wburns
 * @since 9.0
 */
public class IterableIterationResult {
   private final Set<Integer> finishedSegments;
   private final OperationStatus statusCode;
   private final List<CacheEntry> entries;
   private final CompatInfo compatInfo;
   private final boolean metadata;

   IterableIterationResult(Set<Integer> finishedSegments, OperationStatus statusCode, List<CacheEntry> entries, CompatInfo compatInfo, boolean metadata) {
      this.finishedSegments = finishedSegments;
      this.statusCode = statusCode;
      this.entries = entries;
      this.compatInfo = compatInfo;
      this.metadata = metadata;
   }

   public OperationStatus getStatusCode() {
      return statusCode;
   }

   public List<CacheEntry> getEntries() {
      return entries;
   }

   public boolean isMetadata() {
      return metadata;
   }

   public boolean isCompatEnabled() {
      return compatInfo.enabled;
   }

   public byte[] segmentsToBytes() {
      BitSet bs = new BitSet();
      finishedSegments.stream().forEach(bs::set);
      return bs.toByteArray();
   }

   public Object unbox(Object value) {
      if(value == null) return null;
      return compatInfo.valueEncoder.fromStorage(value);
   }

   @Override
   public String toString() {
      return "IterableIterationResult{" +
            "finishedSegments=" + finishedSegments +
            ", statusCode=" + statusCode +
            ", entries=" + entries +
            ", compatInfo=" + compatInfo +
            ", metadata=" + metadata +
            '}';
   }
}

==> infinispan-server-hotrod-14.0.3.Final-sources.jar: org/infinispan/server/hotrod/iteration/IterableIterationResult.java <==
package org.infinispan.server.hotrod.iteration;

import java.util.BitSet;
import java.util.List;
import java.util.Set;
import java.util.function.Function;

import org.infinispan.container.entries.CacheEntry;
import org.infinispan.server.hotrod.OperationStatus;

/**
 * @author wburns
 * @since 9.0
 */
public class IterableIterationResult {
   private final Set<Integer> finishedSegments;
   private final OperationStatus statusCode;
   private final List<CacheEntry> entries;
   private final boolean metadata;
   private final Function<Object, Object> resultFunction;

   IterableIterationResult(Set<Integer> finishedSegments, OperationStatus statusCode, List<CacheEntry> entries, boolean metadata, Function<Object, Object> resultFunction) {
      this.finishedSegments = finishedSegments;
      this.statusCode = statusCode;
      this.entries = entries;
      this.metadata = metadata;
      this.resultFunction = resultFunction;
   }

   public OperationStatus getStatusCode() {
      return statusCode;
   }

   public List<CacheEntry> getEntries() {
      return entries;
   }

   public boolean isMetadata() {
      return metadata;
   }

   public byte[] segmentsToBytes() {
      BitSet bs = new BitSet();
      finishedSegments.stream().forEach(bs::set);
      return bs.toByteArray();
   }

   @Override
   public String toString() {
      return "IterableIterationResult{" +
            "finishedSegments=" + finishedSegments +
            ", statusCode=" + statusCode +
            ", entries=" + entries +
            ", metadata=" + metadata +
            '}';
   }

   public Function<Object, Object> getResultFunction() {
      return resultFunction;
   }
}
